<?php

/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package iowa-civil
 */

?>

<!doctype html>
<html <?php language_attributes(); ?>>

<head>
	<meta charset="<?php bloginfo('charset'); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">
	<link rel="preload" href="<?php echo get_template_directory_uri(); ?>/assets/fonts/Rubik-Bold.woff2" as="font" type="font/woff2" crossorigin>
	<link rel="preload" href="<?php echo get_template_directory_uri(); ?>/assets/fonts/Rubik-Regular.woff2" as="font" type="font/woff2" crossorigin>
	<link rel="preload" href="<?php echo get_template_directory_uri(); ?>/assets/fonts/Rubik-Medium.woff2" as="font" type="font/woff2" crossorigin>
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
	<?php wp_body_open(); ?>
	<div id="page" class="site">
		<header id="masthead" class="site-header">
			<?php
			$phone_number =  get_field('phone_number', 'option');
			$email 		  =  get_field('email', 'option');
			if (!empty($phone_number) || !empty($email)) { ?>
				<div class="top-header">
					<div class="container">
						<div class="row">
							<div class="col-lg-12 text-end">
								<?php
								if (!empty($phone_number)) { ?>
									<a href="<?php echo $phone_number['url']; ?>" title="<?php echo $phone_number['title']; ?>"><span class="icon"><i class="fas fa-phone-alt"></i></span><span class="call-us"><?php echo $phone_number['title']; ?></span></a>
								<?php
								}
								if (!empty($email)) { ?>
									<a href="mailto:<?php echo $email; ?>" title="<?php echo $email; ?>"><span class="icon"><i class="fas fa-envelope"></i></span> <?php echo $email; ?></a>
								<?php } ?>
							</div>
						</div>
					</div>
				</div>
			<?php } ?>
			<div class="bottom-header">
				<div class="container">
					<div class="row align-items-center">
						<div class="col-lg-3">
							<div class="site-branding for-des">
								<?php
								the_custom_logo();
								?>
							</div><!-- .site-branding -->
							<?php
							$site_name			= get_bloginfo('name');
							$mobile_logo	=  get_field('mobile_device_logo', 'option');
							if (!empty($mobile_logo)) { ?>
								<div class="site-branding for-mob">
									<a href="<?php echo home_url(); ?>" class="custom-logo-link" title="<?php echo $site_name; ?>">
										<img width="230" height="53" src="<?php echo $mobile_logo; ?>" alt="<?php echo $site_name; ?>">
									</a>
								</div>
							<?php } ?>
						</div>
						<div class="col-lg-9">
							<div class="header-menu">
								<nav id="site-navigation" class="main-navigation">
									<?php
									if (!empty($phone_number)) { ?>
										<a href="<?php echo $phone_number['url']; ?>" class="call-icon for-mob" title="<?php echo $phone_number['title']; ?>"><span><i class="fas fa-phone-alt"></i></span></a>
									<?php } ?>
									<button type="button" class="menu-toggle" aria-label="Hamburger Menu" aria-controls="primary-menu" aria-expanded="false">
										<span></span>
										<span></span>
										<span></span>
									</button>
									<div class="header-mobile-menu">
										<?php
										wp_nav_menu(
											array(
												'theme_location' => 'menu-1',
												'menu_id'        => 'primary-menu',
											)
										);
										?>
										<?php
										$modal_title = get_field('modal_title', 'option');
										if (!empty($modal_title)) { ?>
											<button type="button" aria-label="<?php echo $modal_title; ?>" data-bs-toggle="modal" data-bs-target="#schedule_an_estimate_Modal" class="sec-btn for-mob"><span><?php echo $modal_title; ?></span></button>
										<?php } ?>
									</div>
								</nav><!-- #site-navigation -->
							</div>
						</div>
					</div>
				</div>
			</div>

		</header><!-- #masthead -->